from setuptools import setup, find_packages
setup(
    name='YPG', 
    version='0.2',
    packages=find_packages(),
    author='DEOM',
    author_email='tvvvyvv@gmail.com',
    description='Simple',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',  
        'Operating System :: OS Independent',
        ]
     ) 